% % read from file
clear
h_tbl = readtable('joined_human.txt');
m_tbl = readtable('joined_mouse.txt');

h_names = table2cell(h_tbl(:,5));
m_names = table2cell(m_tbl(:,5));

% % convert to matrix
h_arr = max(table2array(h_tbl(:,[7:19])),0);
m_arr = max(table2array(m_tbl(:,[7:19])),0);

% % re calculate one to one orthology
h_idx_map = strcmp(table2cell(h_tbl(:,19)),'1H:1M');
h_idx_map = h_idx_map | strcmp(table2cell(h_tbl(:,19)),'1H:1M(L)');

m_idx_map = strcmp(table2cell(m_tbl(:,19)),'1H:1M');
m_idx_map = m_idx_map | strcmp(table2cell(m_tbl(:,19)),'1H:1M(L)');

% % update table headers
h_tbl.Properties.VariableNames{23} = 'h_neural_propn';
m_tbl.Properties.VariableNames{23} = 'm_neural_propn';
h_tbl.Properties.VariableNames{25} = 'h_drg_tn_log_ratio';
m_tbl.Properties.VariableNames{25} = 'm_drg_oe_log_ratio';

% % remove tibial nerve
h_exp = h_arr_final_norm(:,[1:8,10:end]);
h_extra = h_arr_final_norm(:,[9]);
m_exp = m_arr_final_norm(:,[1:8,10:end]);
m_extra = m_arr_final_norm(:,[9]);

% % update flags

h_idx_coding = strcmp(table2cell(h_tbl(:,2)),'protein_coding');
m_idx_coding = strcmp(table2cell(m_tbl(:,2)),'protein_coding');

h_idx_map = strcmp(table2cell(h_tbl(:,19)),'1H:1M');
h_idx_map = h_idx_map | strcmp(table2cell(h_tbl(:,19)),'1H:1M(L)');

m_idx_map = strcmp(table2cell(m_tbl(:,19)),'1H:1M');
m_idx_map = m_idx_map | strcmp(table2cell(m_tbl(:,19)),'1H:1M(L)');

% % upper quartile normalization

h_factor = prctile(h_exp(h_idx_coding & ~h_removelist,:),75);
m_factor = prctile(m_exp(m_idx_coding & ~m_removelist,:),75);
h_extra_factor = prctile(h_extra(h_idx_coding),75);
m_extra_factor = prctile(m_extra(m_idx_coding),75);

h_corr = h_exp ./ repmat(h_factor,size(h_exp,1),1);
m_corr = m_exp ./ repmat(m_factor,size(m_exp,1),1);
h_extra_corr = h_extra / h_extra_factor;
m_extra_corr = m_extra / m_extra_factor;

% % update more flags

h_expressed = max(h_corr'> (0.75 / h_factor(:,1)) )';
m_expressed = max(m_corr'> (0.75 / h_factor(:,1)) )';

corr_thresh = 0.75 / h_factor(:,1);

h_idx_known = strcmp(table2cell(h_tbl(:,3)),'KNOWN');
m_idx_known = strcmp(table2cell(m_tbl(:,3)),'KNOWN');

% % update foldchange

h_ratio = round(log2((h_corr(:,1) + 0.01) ./ (h_extra_corr + 0.01)),5);
h_tbl(:,25) = array2table(h_ratio);
m_ratio = round(log2((m_corr(:,1) + 0.01) ./ (m_extra_corr + 0.01)),5);
m_tbl(:,25) = array2table(m_ratio);

% % update proportions

h_row_sum = repmat(sum(h_corr')',1,size(h_exp,2));
h_row_sum = h_row_sum + (h_row_sum == 0);

m_row_sum = repmat(sum(m_corr')',1,size(m_exp,2));
m_row_sum = m_row_sum + (m_row_sum == 0);

h_prop = h_corr ./ h_row_sum;
m_prop = m_corr ./ m_row_sum;

% % update entropy
h_lprop = log2(h_prop);
h_lprop(isinf(h_lprop)) = 0;

m_lprop = log2(m_prop);
m_lprop(isinf(m_lprop)) = 0;

h_entr = round(- sum(h_prop' .* h_lprop')' ./ log2(size(h_prop,2)),5) ;
m_entr = round(- sum(m_prop' .* m_lprop')' ./ log2(size(m_prop,2)),5) ;

h_entr(max(h_prop')' == 0) = 1;
m_entr(max(m_prop')' == 0) = 1;

h_tbl(:,21) = array2table(h_entr);
m_tbl(:,21) = array2table(m_entr);

% % update drg enrichment

h_drg_en = round((1 - h_entr) .* h_prop(:,1),5);
m_drg_en = round((1 - m_entr) .* m_prop(:,1),5);

h_tbl(:,22) = array2table(h_drg_en);
m_tbl(:,22) = array2table(m_drg_en);


% % update neural proportion

h_neu_prop = [sum(h_prop(:,1:6),2), h_prop(:,7:end)];
m_neu_prop = [sum(m_prop(:,1:6),2), m_prop(:,7:end)];

h_tbl(:,23) = array2table(round(h_neu_prop(:,1),5));
m_tbl(:,23) = array2table(round(m_neu_prop(:,1),5));
